const app = window.app
import * as device from 'device'
import * as fs from './fs.js'
import * as date from './date.js'
import * as tags from './tags.js'
import * as list from './list.js'
import * as view from './view.js'
import * as editor from './editor.js'

export async function Init() {
    await populate()

    await Load()
    window.addEventListener('hashchange', CheckHash)
}

export async function CheckHash() {
    if(window.location.hash === '') {
        Open(date.Current())
        return
    }

    if(window.location.hash.slice(1) === app.name) {
        return
    }

    await Load()
    editor.Load()
}

export async function populate() {
    let f = await device.Entries()
    // TODO: refactor and check filetype
    let n = [ ...f.entries() ]
        .map(([ n, h ]) => [ fs.Basename(n), h ])
        .filter(([ n ]) => date.Is(n) && Date.parse(n) < Date.now())

    app.all = new Map(n)
    order()
}

export function order() {
    app.all = new Map(
        [ ...app.all.entries() ]
            .sort(([ a ], [ b ]) => {
                return new Date(b) - new Date(a)
            })
    )
}

export function Open(sName) {
    window.location.hash = sName
}

export function Next() {
    let p
    for(let c of app.all.keys()) {
        if(c == app.name) {
            break
        }
        p = c
    }
    Open(p ?? date.Current())
}

export function Prev() {
    let p
    for(let c of app.all.keys()) {
        if(p == app.name) {
            Open(c)
            return
        }
        p = c
    }
    Open(app.all.keys().next().value)
}

export function getIndex() {
    if(!this.handle) {
        return app.list.length - 1
    } else {
        return app.list.indexOf(this.name)
    }
}

// TODO: remove app.disk, change the flow so content is fed directly into new editor state
export async function Load() {
    app.name = window.location.hash.substring(1)
    switch(app.name) {
        case tags.pageHash:
            app.handle = null
            app.disk = await tags.Rank()
            break

        case list.pageHash:
            app.handle = null
            app.disk = await list.All()
            break

        default:
            app.handle = app.all.get(app.name)
            await ReadDisk()
            break
    }
        
    view.Title(app.name)
}

export async function ReadDisk() {
    app.disk = await fs.Text(app.handle)
}

export async function Save() {
    if(app.handle == null) {
        if(date.Is(app.name)) {
            app.handle = await device.Create(Filename())
            app.all.set(app.name, app.handle)
            order()
        } else {
            return
        }
    }

    await device.Write(app.handle, editor.Content())
    await ReadDisk()
}

export function Filename() {
    return app.name + '.md'
}